##  Linking an Existing Initiative Fact Sheet to an Existing Jira Work Item
Connect an existing initiative to an existing Jira work item to keep your data consistent across tools. This sets up synchronization between the two, ensuring consistent tracking and visibility.
To link an initiative fact sheet to a Jira work item, do the following:
  1. Navigate to the initiative fact sheet.
  2. Open the Agile Tracking tab.
  3. Choose Set up Sync and select Link to an Existing Work Item in Atlassian Jira to connect the fact sheet with a Jira work item.
  4. Choose the Jira work item that you want to link to.
  5. Choose Create and Sync.


Fact Sheet With a Linked Work Item
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof2cc52d0f0dd4964a534b9640a210510_LowRes.png)
